@@ -20,18 +20,15 @@ pub(in crate::biome) mod schema;
 
 use diesel::r2d2::{ConnectionManager, Pool};
 
-#[cfg(feature = "oauth-user-list")]
-use super::OAuthUserIter;
 use super::{
-    InsertableOAuthUserSession, OAuthUser, OAuthUserSession, OAuthUserSessionStore,
+    InsertableOAuthUserSession, OAuthUser, OAuthUserIter, OAuthUserSession, OAuthUserSessionStore,
     OAuthUserSessionStoreError,
 };
 
-#[cfg(feature = "oauth-user-list")]
-use operations::list_users::OAuthUserSessionStoreListUsers as _;
 use operations::{
     add_session::OAuthUserSessionStoreAddSession as _,
     get_session::OAuthUserSessionStoreGetSession as _, get_user::OAuthUserSessionStoreGetUser as _,
+    list_users::OAuthUserSessionStoreListUsers as _,
     remove_session::OAuthUserSessionStoreRemoveSession as _,
     update_session::OAuthUserSessionStoreUpdateSession as _, OAuthUserSessionStoreOperations,
 };
@@ -86,7 +83,6 @@ impl OAuthUserSessionStore for DieselOAuthUserSessionStore<diesel::sqlite::Sqlit
         OAuthUserSessionStoreOperations::new(&*connection).get_user(subject)
     }
 
-    #[cfg(feature = "oauth-user-list")]
     fn list_users(&self) -> Result<OAuthUserIter, OAuthUserSessionStoreError> {
         let connection = self.connection_pool.get()?;
         OAuthUserSessionStoreOperations::new(&*connection).list_users()
@@ -138,7 +134,6 @@ impl OAuthUserSessionStore for DieselOAuthUserSessionStore<diesel::pg::PgConnect
         OAuthUserSessionStoreOperations::new(&*connection).get_user(subject)
     }
 
-    #[cfg(feature = "oauth-user-list")]
     fn list_users(&self) -> Result<OAuthUserIter, OAuthUserSessionStoreError> {
         let connection = self.connection_pool.get()?;
         OAuthUserSessionStoreOperations::new(&*connection).list_users()
@@ -475,7 +470,6 @@ pub mod tests {
         assert_eq!(stored_session2.oauth_access_token(), oauth_access_token2);
     }
 
-    #[cfg(feature = "oauth-user-list")]
     /// Verify that a SQLite-backed `DieselOAuthUserSessionStore` correctly supports inserting and
     /// and listing OAuth users.
     ///
