@@ -12,6 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+use crate::error::InternalError;
 use crate::network::dispatch::{
     ConnectionId, DispatchError, Handler, MessageContext, MessageSender,
 };
@@ -26,8 +27,8 @@ use crate::protos::prelude::*;
 
 use crate::network::auth::{
     state_machine::trust_v0::{TrustV0AuthorizationAction, TrustV0AuthorizationState},
-    AuthorizationActionError, AuthorizationManagerStateMachine, AuthorizationRemoteAction,
-    AuthorizationRemoteState, Identity,
+    AuthorizationAcceptingAction, AuthorizationAcceptingState, AuthorizationActionError,
+    AuthorizationManagerStateMachine, Identity,
 };
 
 pub struct AuthorizedHandler {
@@ -59,9 +60,9 @@ impl Handler for AuthorizedHandler {
             "Received authorize message from {}",
             context.source_connection_id()
         );
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::TrustV0(TrustV0AuthorizationAction::RemoteAuthorizing),
+            AuthorizationAcceptingAction::TrustV0(TrustV0AuthorizationAction::RemoteAuthorizing),
         ) {
             Err(err) => {
                 warn!(
@@ -108,9 +109,9 @@ impl Handler for ConnectRequestHandler {
         sender: &dyn MessageSender<Self::Source>,
     ) -> Result<(), DispatchError> {
         let connect_request = ConnectRequest::from_proto(msg)?;
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::Connecting,
+            AuthorizationAcceptingAction::Connecting,
         ) {
             Err(AuthorizationActionError::AlreadyConnecting) => {
                 debug!(
@@ -125,7 +126,7 @@ impl Handler for ConnectRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationRemoteState::TrustV0(TrustV0AuthorizationState::Connecting)) => {
+            Ok(AuthorizationAcceptingState::TrustV0(TrustV0AuthorizationState::Connecting)) => {
                 debug!("Beginning handshake for {}", context.source_connection_id(),);
                 // Send a connect request of our own
 
@@ -164,7 +165,11 @@ impl Handler for ConnectRequestHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         Ok(())
@@ -174,11 +179,15 @@ impl Handler for ConnectRequestHandler {
 /// Handler for the ConnectResponse Authorization Message Type
 pub struct ConnectResponseHandler {
     identity: String,
+    auth_manager: AuthorizationManagerStateMachine,
 }
 
 impl ConnectResponseHandler {
-    pub fn new(identity: String) -> Self {
-        ConnectResponseHandler { identity }
+    pub fn new(identity: String, auth_manager: AuthorizationManagerStateMachine) -> Self {
+        ConnectResponseHandler {
+            identity,
+            auth_manager,
+        }
     }
 }
 
@@ -204,6 +213,17 @@ impl Handler for ConnectResponseHandler {
             connect_response,
         );
 
+        self.auth_manager
+            .set_local_authorization(
+                context.source_connection_id(),
+                Identity::Trust {
+                    identity: self.identity.to_string(),
+                },
+            )
+            .map_err(|err| {
+                DispatchError::HandleError(format!("Unable to set local authorization: {}", err))
+            })?;
+
         if connect_response
             .accepted_authorization_types
             .iter()
@@ -252,9 +272,9 @@ impl Handler for TrustRequestHandler {
         sender: &dyn MessageSender<Self::Source>,
     ) -> Result<(), DispatchError> {
         let trust_request = TrustRequest::from_proto(msg)?;
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::TrustV0(TrustV0AuthorizationAction::TrustIdentifyingV0(
+            AuthorizationAcceptingAction::TrustV0(TrustV0AuthorizationAction::TrustIdentifyingV0(
                 Identity::Trust {
                     identity: trust_request.identity,
                 },
@@ -267,10 +287,10 @@ impl Handler for TrustRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationRemoteState::TrustV0(TrustV0AuthorizationState::RemoteIdentified(
-                Identity::Trust { identity },
-            )))
-            | Ok(AuthorizationRemoteState::Done(Identity::Trust { identity })) => {
+            Ok(AuthorizationAcceptingState::TrustV0(
+                TrustV0AuthorizationState::RemoteIdentified(Identity::Trust { identity }),
+            ))
+            | Ok(AuthorizationAcceptingState::Done(Identity::Trust { identity })) => {
                 debug!(
                     "Sending Authorized message to connection {} after receiving identity {}",
                     context.source_connection_id(),
@@ -286,7 +306,11 @@ impl Handler for TrustRequestHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
         Ok(())
     }
@@ -347,14 +371,13 @@ mod tests {
         auth_msg.set_payload(msg.write_to_bytes().unwrap());
         let msg_bytes = auth_msg.write_to_bytes().unwrap();
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -423,14 +446,13 @@ mod tests {
         auth_msg.set_payload(msg.write_to_bytes().unwrap());
         let msg_bytes = auth_msg.write_to_bytes().unwrap();
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (_, msg_bytes) = mock_sender
             .next_outbound()
@@ -482,14 +504,13 @@ mod tests {
         auth_msg.set_payload(msg.write_to_bytes().unwrap());
 
         let msg_bytes = auth_msg.write_to_bytes().unwrap();
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (_, msg_bytes) = mock_sender
             .next_outbound()
@@ -506,14 +527,13 @@ mod tests {
         auth_msg.set_message_type(authorization::AuthorizationMessageType::TRUST_REQUEST);
         auth_msg.set_payload(trust_req.write_to_bytes().unwrap());
         let msg_bytes = auth_msg.write_to_bytes().unwrap();
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (_, msg_bytes) = mock_sender
             .next_outbound()
