@@ -16,13 +16,14 @@
 
 use cylinder::{PublicKey, Signature, Signer, Verifier};
 
+use crate::error::InternalError;
 use crate::network::auth::state_machine::challenge_v1::{
-    ChallengeAuthorizationLocalAction, ChallengeAuthorizationLocalState,
-    ChallengeAuthorizationRemoteAction, ChallengeAuthorizationRemoteState,
+    ChallengeAuthorizationAcceptingAction, ChallengeAuthorizationAcceptingState,
+    ChallengeAuthorizationInitiatingAction, ChallengeAuthorizationInitiatingState,
 };
 use crate::network::auth::{
-    AuthorizationLocalAction, AuthorizationLocalState, AuthorizationManagerStateMachine,
-    AuthorizationMessage, AuthorizationRemoteAction, AuthorizationRemoteState, Identity,
+    AuthorizationAcceptingAction, AuthorizationAcceptingState, AuthorizationInitiatingAction,
+    AuthorizationInitiatingState, AuthorizationManagerStateMachine, AuthorizationMessage, Identity,
 };
 use crate::network::dispatch::{
     ConnectionId, DispatchError, Handler, MessageContext, MessageSender,
@@ -76,10 +77,10 @@ impl Handler for AuthChallengeNonceRequestHandler {
             context.source_connection_id()
         );
 
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::Challenge(
-                ChallengeAuthorizationRemoteAction::ReceiveAuthChallengeNonceRequest,
+            AuthorizationAcceptingAction::Challenge(
+                ChallengeAuthorizationAcceptingAction::ReceiveAuthChallengeNonceRequest,
             ),
         ) {
             Err(err) => {
@@ -92,8 +93,8 @@ impl Handler for AuthChallengeNonceRequestHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationRemoteState::Challenge(
-                ChallengeAuthorizationRemoteState::ReceivedAuthChallengeNonce,
+            Ok(AuthorizationAcceptingState::Challenge(
+                ChallengeAuthorizationAcceptingState::ReceivedAuthChallengeNonce,
             )) => {
                 let auth_msg =
                     AuthorizationMessage::AuthChallengeNonceResponse(AuthChallengeNonceResponse {
@@ -112,10 +113,10 @@ impl Handler for AuthChallengeNonceRequestHandler {
 
                 if self
                     .auth_manager
-                    .next_remote_state(
+                    .next_accepting_state(
                         context.source_connection_id(),
-                        AuthorizationRemoteAction::Challenge(
-                            ChallengeAuthorizationRemoteAction::SendAuthChallengeNonceResponse,
+                        AuthorizationAcceptingAction::Challenge(
+                            ChallengeAuthorizationAcceptingAction::SendAuthChallengeNonceResponse,
                         ),
                     )
                     .is_err()
@@ -126,7 +127,11 @@ impl Handler for AuthChallengeNonceRequestHandler {
                     );
                 };
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         Ok(())
@@ -205,10 +210,10 @@ impl Handler for AuthChallengeNonceResponseHandler {
             })
             .collect::<Result<Vec<SubmitRequest>, DispatchError>>()?;
 
-        match self.auth_manager.next_local_state(
+        match self.auth_manager.next_initiating_state(
             context.source_connection_id(),
-            AuthorizationLocalAction::Challenge(
-                ChallengeAuthorizationLocalAction::ReceiveAuthChallengeNonceResponse,
+            AuthorizationInitiatingAction::Challenge(
+                ChallengeAuthorizationInitiatingAction::ReceiveAuthChallengeNonceResponse,
             ),
         ) {
             Err(err) => {
@@ -221,8 +226,8 @@ impl Handler for AuthChallengeNonceResponseHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationLocalState::Challenge(
-                ChallengeAuthorizationLocalState::ReceivedAuthChallengeNonceResponse,
+            Ok(AuthorizationInitiatingState::Challenge(
+                ChallengeAuthorizationInitiatingState::ReceivedAuthChallengeNonceResponse,
             )) => {
                 let auth_msg =
                     AuthorizationMessage::AuthChallengeSubmitRequest(AuthChallengeSubmitRequest {
@@ -235,10 +240,10 @@ impl Handler for AuthChallengeNonceResponseHandler {
 
                 if self
                     .auth_manager
-                    .next_local_state(
+                    .next_initiating_state(
                         context.source_connection_id(),
-                        AuthorizationLocalAction::Challenge(
-                            ChallengeAuthorizationLocalAction::SendAuthChallengeSubmitRequest,
+                        AuthorizationInitiatingAction::Challenge(
+                            ChallengeAuthorizationInitiatingAction::SendAuthChallengeSubmitRequest,
                         ),
                     )
                     .is_err()
@@ -255,7 +260,11 @@ impl Handler for AuthChallengeNonceResponseHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         Ok(())
@@ -365,12 +374,12 @@ impl Handler for AuthChallengeSubmitRequestHandler {
             return Ok(());
         };
 
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::Challenge(
-                ChallengeAuthorizationRemoteAction::ReceiveAuthChallengeSubmitRequest(
+            AuthorizationAcceptingAction::Challenge(
+                ChallengeAuthorizationAcceptingAction::ReceiveAuthChallengeSubmitRequest(
                     Identity::Challenge {
-                        public_key: identity,
+                        public_key: identity.clone(),
                     },
                 ),
             ),
@@ -385,11 +394,14 @@ impl Handler for AuthChallengeSubmitRequestHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationRemoteState::Challenge(
-                ChallengeAuthorizationRemoteState::ReceivedAuthChallengeSubmitRequest(_),
+            Ok(AuthorizationAcceptingState::Challenge(
+                ChallengeAuthorizationAcceptingState::ReceivedAuthChallengeSubmitRequest(_),
             )) => {
-                let auth_msg =
-                    AuthorizationMessage::AuthChallengeSubmitResponse(AuthChallengeSubmitResponse);
+                let auth_msg = AuthorizationMessage::AuthChallengeSubmitResponse(
+                    AuthChallengeSubmitResponse {
+                        public_key: identity.into_bytes(),
+                    },
+                );
 
                 let msg_bytes = IntoBytes::<network::NetworkMessage>::into_bytes(
                     NetworkMessage::from(auth_msg),
@@ -401,15 +413,19 @@ impl Handler for AuthChallengeSubmitRequestHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         if self
             .auth_manager
-            .next_remote_state(
+            .next_accepting_state(
                 context.source_connection_id(),
-                AuthorizationRemoteAction::Challenge(
-                    ChallengeAuthorizationRemoteAction::SendAuthChallengeSubmitResponse,
+                AuthorizationAcceptingAction::Challenge(
+                    ChallengeAuthorizationAcceptingAction::SendAuthChallengeSubmitResponse,
                 ),
             )
             .is_err()
@@ -444,7 +460,7 @@ impl Handler for AuthChallengeSubmitResponseHandler {
 
     fn handle(
         &self,
-        _msg: Self::Message,
+        msg: Self::Message,
         context: &MessageContext<Self::Source, Self::MessageType>,
         sender: &dyn MessageSender<Self::Source>,
     ) -> Result<(), DispatchError> {
@@ -453,10 +469,18 @@ impl Handler for AuthChallengeSubmitResponseHandler {
             context.source_connection_id()
         );
 
-        match self.auth_manager.next_local_state(
+        let submit_msg = AuthChallengeSubmitResponse::from_proto(msg)?;
+
+        let public_key = submit_msg.public_key;
+
+        match self.auth_manager.next_initiating_state(
             context.source_connection_id(),
-            AuthorizationLocalAction::Challenge(
-                ChallengeAuthorizationLocalAction::ReceiveAuthChallengeSubmitResponse,
+            AuthorizationInitiatingAction::Challenge(
+                ChallengeAuthorizationInitiatingAction::ReceiveAuthChallengeSubmitResponse(
+                    Identity::Challenge {
+                        public_key: public_key::PublicKey::from_bytes(public_key),
+                    },
+                ),
             ),
         ) {
             Err(err) => {
@@ -469,7 +493,7 @@ impl Handler for AuthChallengeSubmitResponseHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationLocalState::Authorized) => {
+            Ok(AuthorizationInitiatingState::Authorized) => {
                 let auth_msg = AuthorizationMessage::AuthComplete(AuthComplete);
                 let msg_bytes = IntoBytes::<network::NetworkMessage>::into_bytes(
                     NetworkMessage::from(auth_msg),
@@ -480,9 +504,9 @@ impl Handler for AuthChallengeSubmitResponseHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
 
-                match self.auth_manager.next_local_state(
+                match self.auth_manager.next_initiating_state(
                     context.source_connection_id(),
-                    AuthorizationLocalAction::SendAuthComplete,
+                    AuthorizationInitiatingAction::SendAuthComplete,
                 ) {
                     Err(err) => {
                         send_authorization_error(
@@ -494,14 +518,20 @@ impl Handler for AuthChallengeSubmitResponseHandler {
                         )?;
                         return Ok(());
                     }
-                    Ok(AuthorizationLocalState::WaitForComplete) => (),
-                    Ok(AuthorizationLocalState::AuthorizedAndComplete) => (),
+                    Ok(AuthorizationInitiatingState::WaitForComplete) => (),
+                    Ok(AuthorizationInitiatingState::AuthorizedAndComplete) => (),
                     Ok(next_state) => {
-                        panic!("Should not have been able to transition to {}", next_state)
+                        return Err(DispatchError::InternalError(InternalError::with_message(
+                            format!("Should not have been able to transition to {}", next_state),
+                        )))
                     }
                 };
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         };
         Ok(())
     }
@@ -520,7 +550,7 @@ mod tests {
     };
     use protobuf::Message;
 
-    use crate::network::auth::state_machine::challenge_v1::ChallengeAuthorizationLocalState;
+    use crate::network::auth::state_machine::challenge_v1::ChallengeAuthorizationInitiatingState;
     use crate::network::auth::{
         AuthorizationDispatchBuilder, ConnectionAuthorizationType, ManagedAuthorizationState,
     };
@@ -551,9 +581,10 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::WaitingForAuthProtocolResponse,
-                    remote_state: AuthorizationRemoteState::SentAuthProtocolResponse,
+                    initiating_state: AuthorizationInitiatingState::WaitingForAuthProtocolResponse,
+                    accepting_state: AuthorizationAcceptingState::SentAuthProtocolResponse,
                     received_complete: true,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -593,14 +624,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -623,14 +653,14 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::Challenge(
-                ChallengeAuthorizationLocalState::WaitingForAuthChallengeNonceResponse
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::Challenge(
+                ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeNonceResponse
             ),
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::SentAuthProtocolResponse
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::SentAuthProtocolResponse
         );
         assert_eq!(managed_state.received_complete, true);
     }
@@ -655,11 +685,12 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Challenge(
-                        ChallengeAuthorizationLocalState::WaitingForAuthChallengeNonceResponse,
+                    initiating_state: AuthorizationInitiatingState::Challenge(
+                        ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeNonceResponse,
                     ),
-                    remote_state: AuthorizationRemoteState::SentAuthProtocolResponse,
+                    accepting_state: AuthorizationAcceptingState::SentAuthProtocolResponse,
                     received_complete: true,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -696,14 +727,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -728,15 +758,15 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::Challenge(
-                ChallengeAuthorizationLocalState::WaitingForAuthChallengeNonceResponse
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::Challenge(
+                ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeNonceResponse
             ),
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Challenge(
-                ChallengeAuthorizationRemoteState::WaitingForAuthChallengeSubmitRequest
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Challenge(
+                ChallengeAuthorizationAcceptingState::WaitingForAuthChallengeSubmitRequest
             )
         );
         assert_eq!(managed_state.received_complete, true);
@@ -762,13 +792,14 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Challenge(
-                        ChallengeAuthorizationLocalState::WaitingForAuthChallengeNonceResponse,
+                    initiating_state: AuthorizationInitiatingState::Challenge(
+                        ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeNonceResponse,
                     ),
-                    remote_state: AuthorizationRemoteState::Challenge(
-                        ChallengeAuthorizationRemoteState::WaitingForAuthChallengeSubmitRequest,
+                    accepting_state: AuthorizationAcceptingState::Challenge(
+                        ChallengeAuthorizationAcceptingState::WaitingForAuthChallengeSubmitRequest,
                     ),
                     received_complete: true,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -805,14 +836,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -852,15 +882,15 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::Challenge(
-                ChallengeAuthorizationLocalState::WaitingForAuthChallengeSubmitResponse
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::Challenge(
+                ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeSubmitResponse
             ),
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Challenge(
-                ChallengeAuthorizationRemoteState::WaitingForAuthChallengeSubmitRequest
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Challenge(
+                ChallengeAuthorizationAcceptingState::WaitingForAuthChallengeSubmitRequest
             )
         );
         assert_eq!(managed_state.received_complete, true);
@@ -883,17 +913,18 @@ mod tests {
             .expect("lock poisoned")
             .states
             .insert(
-                connection_id.to_string(),
-                ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Challenge(
-                        ChallengeAuthorizationLocalState::WaitingForAuthChallengeSubmitResponse,
-                    ),
-                    remote_state: AuthorizationRemoteState::Challenge(
-                        ChallengeAuthorizationRemoteState::WaitingForAuthChallengeSubmitRequest,
-                    ),
-                    received_complete: false,
-                },
-            );
+            connection_id.to_string(),
+            ManagedAuthorizationState {
+                initiating_state: AuthorizationInitiatingState::Challenge(
+                    ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeSubmitResponse,
+                ),
+                accepting_state: AuthorizationAcceptingState::Challenge(
+                    ChallengeAuthorizationAcceptingState::WaitingForAuthChallengeSubmitRequest,
+                ),
+                received_complete: false,
+                local_authorization: None,
+            },
+        );
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
         let local_signer = new_signer();
@@ -939,14 +970,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -969,14 +999,14 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::Challenge(
-                ChallengeAuthorizationLocalState::WaitingForAuthChallengeSubmitResponse
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::Challenge(
+                ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeSubmitResponse
             ),
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Challenge {
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Challenge {
                 public_key: public_key::PublicKey::from_bytes(
                     other_signer
                         .public_key()
@@ -1015,17 +1045,18 @@ mod tests {
             .expect("lock poisoned")
             .states
             .insert(
-                connection_id.to_string(),
-                ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Challenge(
-                        ChallengeAuthorizationLocalState::WaitingForAuthChallengeSubmitResponse,
-                    ),
-                    remote_state: AuthorizationRemoteState::Done(Identity::Challenge {
-                        public_key: public_key.clone(),
-                    }),
-                    received_complete: false,
-                },
-            );
+            connection_id.to_string(),
+            ManagedAuthorizationState {
+                initiating_state: AuthorizationInitiatingState::Challenge(
+                    ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeSubmitResponse,
+                ),
+                accepting_state: AuthorizationAcceptingState::Done(Identity::Challenge {
+                    public_key: public_key.clone(),
+                }),
+                received_complete: false,
+                local_authorization: None,
+            },
+        );
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
         let local_signer = new_signer();
@@ -1055,18 +1086,22 @@ mod tests {
             .expect("Unable to build authorization dispatcher");
 
         let msg_bytes = IntoBytes::<authorization::AuthorizationMessage>::into_bytes(
-            AuthorizationMessage::AuthChallengeSubmitResponse(AuthChallengeSubmitResponse),
+            AuthorizationMessage::AuthChallengeSubmitResponse(AuthChallengeSubmitResponse {
+                public_key: local_signer
+                    .public_key()
+                    .expect("unable to get public key")
+                    .into_bytes(),
+            }),
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -1089,12 +1124,12 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::WaitForComplete
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::WaitForComplete
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Challenge { public_key })
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Challenge { public_key })
         );
         assert_eq!(managed_state.received_complete, false);
     }
@@ -1108,7 +1143,6 @@ mod tests {
     /// 2) the handler should send a AuthComplete
     /// 3) verify state is AuthorizedAndComplete and Done(Identity)
     #[test]
-
     fn auth_challenge_submit_response_complete() {
         let connection_id = "test_connection".to_string();
         let other_signer = new_signer();
@@ -1126,17 +1160,18 @@ mod tests {
             .expect("lock poisoned")
             .states
             .insert(
-                connection_id.to_string(),
-                ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Challenge(
-                        ChallengeAuthorizationLocalState::WaitingForAuthChallengeSubmitResponse,
-                    ),
-                    remote_state: AuthorizationRemoteState::Done(Identity::Challenge {
-                        public_key: public_key.clone(),
-                    }),
-                    received_complete: true,
-                },
-            );
+            connection_id.to_string(),
+            ManagedAuthorizationState {
+                initiating_state: AuthorizationInitiatingState::Challenge(
+                    ChallengeAuthorizationInitiatingState::WaitingForAuthChallengeSubmitResponse,
+                ),
+                accepting_state: AuthorizationAcceptingState::Done(Identity::Challenge {
+                    public_key: public_key.clone(),
+                }),
+                received_complete: true,
+                local_authorization: None,
+            },
+        );
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
         let local_signer = new_signer();
@@ -1166,18 +1201,22 @@ mod tests {
             .expect("Unable to build authorization dispatcher");
 
         let msg_bytes = IntoBytes::<authorization::AuthorizationMessage>::into_bytes(
-            AuthorizationMessage::AuthChallengeSubmitResponse(AuthChallengeSubmitResponse),
+            AuthorizationMessage::AuthChallengeSubmitResponse(AuthChallengeSubmitResponse {
+                public_key: local_signer
+                    .public_key()
+                    .expect("unable to get public key")
+                    .into_bytes(),
+            }),
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -1200,12 +1239,12 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::AuthorizedAndComplete,
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::AuthorizedAndComplete,
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Challenge { public_key })
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Challenge { public_key })
         );
         assert_eq!(managed_state.received_complete, true);
     }
