@@ -14,12 +14,14 @@
 
 //! Message handlers for Trust v1 authorization messages
 
+use crate::error::InternalError;
 use crate::network::auth::state_machine::trust_v1::{
-    TrustAuthorizationLocalAction, TrustAuthorizationRemoteAction, TrustAuthorizationRemoteState,
+    TrustAuthorizationAcceptingAction, TrustAuthorizationAcceptingState,
+    TrustAuthorizationInitiatingAction,
 };
 use crate::network::auth::{
-    AuthorizationLocalAction, AuthorizationLocalState, AuthorizationManagerStateMachine,
-    AuthorizationMessage, AuthorizationRemoteAction, AuthorizationRemoteState, Identity,
+    AuthorizationAcceptingAction, AuthorizationAcceptingState, AuthorizationInitiatingAction,
+    AuthorizationInitiatingState, AuthorizationManagerStateMachine, AuthorizationMessage, Identity,
 };
 use crate::network::dispatch::{
     ConnectionId, DispatchError, Handler, MessageContext, MessageSender,
@@ -64,10 +66,10 @@ impl Handler for AuthTrustRequestHandler {
             context.source_connection_id()
         );
         let trust_request = AuthTrustRequest::from_proto(msg)?;
-        match self.auth_manager.next_remote_state(
+        match self.auth_manager.next_accepting_state(
             context.source_connection_id(),
-            AuthorizationRemoteAction::Trust(
-                TrustAuthorizationRemoteAction::ReceiveAuthTrustRequest(Identity::Trust {
+            AuthorizationAcceptingAction::Trust(
+                TrustAuthorizationAcceptingAction::ReceiveAuthTrustRequest(Identity::Trust {
                     identity: trust_request.identity.to_string(),
                 }),
             ),
@@ -82,8 +84,8 @@ impl Handler for AuthTrustRequestHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationRemoteState::Trust(
-                TrustAuthorizationRemoteState::ReceivedAuthTrustRequest(_),
+            Ok(AuthorizationAcceptingState::Trust(
+                TrustAuthorizationAcceptingState::ReceivedAuthTrustRequest(_),
             )) => {
                 debug!(
                     "Sending trust response to connection {} after receiving identity {}",
@@ -100,15 +102,19 @@ impl Handler for AuthTrustRequestHandler {
                         DispatchError::NetworkSendError((recipient.into(), payload))
                     })?;
             }
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         if self
             .auth_manager
-            .next_remote_state(
+            .next_accepting_state(
                 context.source_connection_id(),
-                AuthorizationRemoteAction::Trust(
-                    TrustAuthorizationRemoteAction::SendAuthTrustResponse,
+                AuthorizationAcceptingAction::Trust(
+                    TrustAuthorizationAcceptingAction::SendAuthTrustResponse,
                 ),
             )
             .is_err()
@@ -150,10 +156,10 @@ impl Handler for AuthTrustResponseHandler {
             "Received authorization trust response from {}",
             context.source_connection_id()
         );
-        match self.auth_manager.next_local_state(
+        match self.auth_manager.next_initiating_state(
             context.source_connection_id(),
-            AuthorizationLocalAction::Trust(
-                TrustAuthorizationLocalAction::ReceiveAuthTrustResponse,
+            AuthorizationInitiatingAction::Trust(
+                TrustAuthorizationInitiatingAction::ReceiveAuthTrustResponse,
             ),
         ) {
             Err(err) => {
@@ -166,8 +172,12 @@ impl Handler for AuthTrustResponseHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationLocalState::Authorized) => (),
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(AuthorizationInitiatingState::Authorized) => (),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         }
 
         let auth_msg = AuthorizationMessage::AuthComplete(AuthComplete);
@@ -179,9 +189,9 @@ impl Handler for AuthTrustResponseHandler {
                 DispatchError::NetworkSendError((recipient.into(), payload))
             })?;
 
-        match self.auth_manager.next_local_state(
+        match self.auth_manager.next_initiating_state(
             context.source_connection_id(),
-            AuthorizationLocalAction::SendAuthComplete,
+            AuthorizationInitiatingAction::SendAuthComplete,
         ) {
             Err(err) => {
                 send_authorization_error(
@@ -193,9 +203,13 @@ impl Handler for AuthTrustResponseHandler {
                 )?;
                 return Ok(());
             }
-            Ok(AuthorizationLocalState::WaitForComplete) => (),
-            Ok(AuthorizationLocalState::AuthorizedAndComplete) => (),
-            Ok(next_state) => panic!("Should not have been able to transition to {}", next_state),
+            Ok(AuthorizationInitiatingState::WaitForComplete) => (),
+            Ok(AuthorizationInitiatingState::AuthorizedAndComplete) => (),
+            Ok(next_state) => {
+                return Err(DispatchError::InternalError(InternalError::with_message(
+                    format!("Should not have been able to transition to {}", next_state),
+                )))
+            }
         };
 
         Ok(())
@@ -214,7 +228,7 @@ mod tests {
     use cylinder::{PublicKey, Signature, VerificationError, Verifier};
     use protobuf::Message;
 
-    use crate::network::auth::state_machine::trust_v1::TrustAuthorizationLocalState;
+    use crate::network::auth::state_machine::trust_v1::TrustAuthorizationInitiatingState;
     use crate::network::auth::AuthorizationDispatchBuilder;
     use crate::network::auth::ManagedAuthorizationState;
     use crate::protocol::authorization::{AuthProtocolResponse, PeerAuthorizationType};
@@ -241,9 +255,10 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::WaitingForAuthProtocolResponse,
-                    remote_state: AuthorizationRemoteState::SentAuthProtocolResponse,
+                    initiating_state: AuthorizationInitiatingState::WaitingForAuthProtocolResponse,
+                    accepting_state: AuthorizationAcceptingState::SentAuthProtocolResponse,
                     received_complete: false,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -275,14 +290,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -318,11 +332,12 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Trust(
-                        TrustAuthorizationLocalState::WaitingForAuthTrustResponse,
+                    initiating_state: AuthorizationInitiatingState::Trust(
+                        TrustAuthorizationInitiatingState::WaitingForAuthTrustResponse,
                     ),
-                    remote_state: AuthorizationRemoteState::SentAuthProtocolResponse,
+                    accepting_state: AuthorizationAcceptingState::SentAuthProtocolResponse,
                     received_complete: false,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -353,14 +368,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -383,14 +397,14 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::Trust(
-                TrustAuthorizationLocalState::WaitingForAuthTrustResponse
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::Trust(
+                TrustAuthorizationInitiatingState::WaitingForAuthTrustResponse
             )
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Trust {
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Trust {
                 identity: "other_identity".to_string()
             })
         );
@@ -419,13 +433,14 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Trust(
-                        TrustAuthorizationLocalState::WaitingForAuthTrustResponse,
+                    initiating_state: AuthorizationInitiatingState::Trust(
+                        TrustAuthorizationInitiatingState::WaitingForAuthTrustResponse,
                     ),
-                    remote_state: AuthorizationRemoteState::Done(Identity::Trust {
+                    accepting_state: AuthorizationAcceptingState::Done(Identity::Trust {
                         identity: "other_identity".to_string(),
                     }),
                     received_complete: false,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -454,14 +469,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -484,12 +498,12 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::WaitForComplete,
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::WaitForComplete,
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Trust {
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Trust {
                 identity: "other_identity".to_string()
             })
         );
@@ -518,13 +532,14 @@ mod tests {
             .insert(
                 connection_id.to_string(),
                 ManagedAuthorizationState {
-                    local_state: AuthorizationLocalState::Trust(
-                        TrustAuthorizationLocalState::WaitingForAuthTrustResponse,
+                    initiating_state: AuthorizationInitiatingState::Trust(
+                        TrustAuthorizationInitiatingState::WaitingForAuthTrustResponse,
                     ),
-                    remote_state: AuthorizationRemoteState::Done(Identity::Trust {
+                    accepting_state: AuthorizationAcceptingState::Done(Identity::Trust {
                         identity: "other_identity".to_string(),
                     }),
                     received_complete: true,
+                    local_authorization: None,
                 },
             );
         let mock_sender = MockSender::new();
@@ -553,14 +568,13 @@ mod tests {
         )
         .expect("Unable to get message bytes");
 
-        assert_eq!(
-            Ok(()),
-            dispatcher.dispatch(
+        assert!(dispatcher
+            .dispatch(
                 connection_id.clone().into(),
                 &NetworkMessageType::AUTHORIZATION,
                 msg_bytes
             )
-        );
+            .is_ok());
 
         let (recipient, message_bytes) = mock_sender
             .next_outbound()
@@ -583,12 +597,12 @@ mod tests {
             .expect("missing managed state for connection id");
 
         assert_eq!(
-            managed_state.local_state,
-            AuthorizationLocalState::AuthorizedAndComplete,
+            managed_state.initiating_state,
+            AuthorizationInitiatingState::AuthorizedAndComplete,
         );
         assert_eq!(
-            managed_state.remote_state,
-            AuthorizationRemoteState::Done(Identity::Trust {
+            managed_state.accepting_state,
+            AuthorizationAcceptingState::Done(Identity::Trust {
                 identity: "other_identity".to_string()
             })
         );
