@@ -340,7 +340,7 @@ impl std::fmt::Display for ConnectionMatrixRecvError {
                 if let Some(ref err) = source {
                     write!(f, "{}: {}", context, err)
                 } else {
-                    f.write_str(&context)
+                    f.write_str(context)
                 }
             }
             ConnectionMatrixRecvError::Shutdown => {
@@ -391,7 +391,7 @@ impl std::fmt::Display for ConnectionMatrixRecvTimeoutError {
                 if let Some(ref err) = source {
                     write!(f, "{}: {}", context, err)
                 } else {
-                    f.write_str(&context)
+                    f.write_str(context)
                 }
             }
             ConnectionMatrixRecvTimeoutError::Shutdown => {
